const data = {
    name: "Animals",
    children: [
        {
            name: "Mammals",
            children: [
                { name: "Dogs" },
                { name: "Cats" },
                { name: "Horses" }
            ]
        },
        {
            name: "Birds",
            children: [
                { name: "Eagles" },
                { name: "Parrots" },
                { name: "Penguins" }
            ]
        },
        {
            name: "Reptiles",
            children: [
                { name: "Snakes" },
                { name: "Lizards" }
            ]
        }
    ]
};

// Dimensions for the tree diagram
const width = 960;
const height = 600;

const svg = d3.select('body').append('svg')
    .attr('width', width)
    .attr('height', height);

const root = d3.hierarchy(data);
const treeLayout = d3.tree().size([height, width - 200]);
treeLayout(root);

const g = svg.append('g').attr('transform', 'translate(100,0)');

// Create links (lines)
const link = g.selectAll('.link')
    .data(root.links())
    .enter().append('path')
    .attr('class', 'link')
    .attr('d', d3.linkHorizontal()
        .x(d => d.y)
        .y(d => d.x));

// Create nodes (circles + labels)
const node = g.selectAll('.node')
    .data(root.descendants())
    .enter().append('g')
    .attr('class', d => "node" + (d.children ? " node--internal" : " node--leaf"))
    .attr('transform', d => `translate(${d.y},${d.x})`);

node.append('circle')
    .attr('r', 5)
    .style('fill', d => d.depth === 0 ? 'black' : d.depth === 1 ? 'blue' : 'green');

node.append('text')
    .attr('dy', 3)
    .attr('x', d => d.children ? -8 : 8)
    .style('text-anchor', d => d.children ? 'end' : 'start')
    .text(d => d.data.name);
